<?php
/**
 * Header Settings
 *
 * Register Header Settings section, settings and controls for Theme Customizer
 *
 * @package ctpress
 * @author Al Mahmud
 * @version 2.0.6
 */

/**
 * Adds post settings in the Customizer
 *
 * @param object $wp_customize / Customizer Object.
 */
function ctpress_customize_register_header_settings( $wp_customize ) {

	/*Add Sections for Header Settings.*/
	$wp_customize->add_section( 'ctpress_section_header', array(
		'title'    		=> esc_html__( 'Header Settings', 'ctpress' ),
		'priority' 		=> 40,
		'panel'    		=> 'ctpress_options_panel',
		'capability'  	=> 'edit_theme_options', /*Capability needed to tweak*/
		'description' 	=> __('Allows you to customize post screen', 'ctpress'), /*//Descriptive tooltip*/
	) );

	/*Get Default Settings.*/
	$default = ctpress_default_options();

	/*Add Menu Details Headline.*/
	$wp_customize->add_control( new ctpress_Customize_Header_Control(
		$wp_customize, 'menu_settings', array(
			'label'    => esc_html__( 'Menu Search Option Hide', 'ctpress' ),
			'section'  => 'ctpress_section_header',
			'settings' => array(),
			'priority' => 10,
		)
	) );

	/*Add Setting and Control for showing menu search.*/
	$wp_customize->add_setting( 'ctpress[menu_search]', array(
		'default'           => $default['menu_search'],
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'ctpress_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'ctpress[menu_search]', array(
		'label'    => esc_html__( 'Hide search', 'ctpress' ),
		'section'  => 'ctpress_section_header',
		'settings' => 'ctpress[menu_search]',
		'type'     => 'checkbox',
		'priority' => 20,
	) );

	/*Add Setting and Control for showing menu search.*/
	$wp_customize->add_setting( 'ctpress[search-position]', array(
		'default'           => $default['search-position'],
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'ctpress_sanitize_select',
	) );

	$wp_customize->add_control( 'ctpress[search-position]', array(
		'label'    => esc_html__( 'Select Menu Position', 'ctpress' ),
		'section'  => 'ctpress_section_header',
		'settings' => 'ctpress[search-position]',
		'type'     => 'select',
		'priority' => 30,
		'choices'  => array(
			1 => esc_html__( 'Logo Area', 'ctpress' ),
            2 => esc_html__( 'Top Right', 'ctpress' ),
            3 => esc_html__( 'Navbar Right', 'ctpress' ),
            4 => esc_html__( 'Footer Right', 'ctpress' ),
		),
	) );

	/*Add Menu Details Headline.*/
	$wp_customize->add_control( new ctpress_Customize_Header_Control(
		$wp_customize, 'menu_show', array(
			'label'    => esc_html__( 'Menu Show or Hide', 'ctpress' ),
			'section'  => 'ctpress_section_header',
			'settings' => array(),
			'priority' => 32,
		)
	) );

	/*Add Setting and Control for showing menu.*/
	$wp_customize->add_setting( 'ctpress[menu_show]', array(
		'default'           => $default['menu_show'],
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'ctpress_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'ctpress[menu_show]', array(
		'label'    => esc_html__( 'Hide Menu', 'ctpress' ),
		'section'  => 'ctpress_section_header',
		'settings' => 'ctpress[menu_show]',
		'type'     => 'checkbox',
		'priority' => 40,
	) );

}
add_action( 'customize_register', 'ctpress_customize_register_header_settings' );

